==> lxqt-config-0.15.0.tar.xz: lxqt-config-0.15.0/lxqt-config-monitor/translations/lxqt-config-monitor_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Opções rápidas</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Vista expandida</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Vista unificada</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Apenas o primeiro</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Apenas o segundo</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Definições do monitor</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Definições guardadas</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="64"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="67"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="70"/>
        <source>Inverted</source>
        <translation>Invertido</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="73"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="77"/>
        <location filename="../managesavedsettings.cpp" line="78"/>
        <source>True</source>
        <translation>Verdadeiro</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="77"/>
        <location filename="../managesavedsettings.cpp" line="78"/>
        <source>False</source>
        <translation>Falso</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="140"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="140"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Manter monitores ligados</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Definições do monitor</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="111"/>
        <source>Fast Menu</source>
        <translation>Menu rápido</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="115"/>
        <source>Set position</source>
        <translation>Definir posição</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="247"/>
        <source>Advanced settings</source>
        <translation>Definições avançadas</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Configuração</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Resolução:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Ativar este ecrã</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Este é o ecrã principal</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Este ecrã expande para outro</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Taxa de atualização:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Rotação:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Informação do ecrã</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="135"/>
        <source>Name: %1
</source>
        <translation>Nome: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="136"/>
        <source>Vendor: %1
</source>
        <translation>Fabricante: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="137"/>
        <source>Serial: %1
</source>
        <translation>Série: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="138"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Tamanho do ecrã: %1 cm x %2 cm
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="139"/>
        <source>Serial number: %1
</source>
        <translation>Número de série: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="140"/>
        <source>EISA device ID: %1
</source>
        <translation>ID EISA do dispositivo: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="161"/>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="162"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="163"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="164"/>
        <source>Inverted</source>
        <translation>Invertido</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="255"/>
        <source>%1 Hz</source>
        <translation>%1 HZ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Gerir definições guardadas</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="82"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="82"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Definições alteradas</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Acha que as definições estão corretas?</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="65"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>Falta %n segundo</numerusform>
            <numerusform>Faltam %n segundos</numerusform>
        </translation>
    </message>
</context>
</TS>

==> lxqt-config_1.3.0.orig.tar.xz: lxqt-config-1.3.0/lxqt-config-monitor/translations/lxqt-config-monitor_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Opções rápidas</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Vista expandida</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Vista unificada</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Apenas o primeiro</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Apenas o segundo</translation>
    </message>
</context>
<context>
    <name>LoadSettings</name>
    <message>
        <location filename="../loadsettings.cpp" line="98"/>
        <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
        <translation>Aplicadas todas as definições padrão para monitores. Se quiser alterar as definições do monitor, utilize lqxt-config-monitor.</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Definições do monitor</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Definições guardadas</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="62"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="65"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="68"/>
        <source>Inverted</source>
        <translation>Invertido</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="71"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>True</source>
        <translation>Verdadeiro</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>False</source>
        <translation>Falso</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Manter monitores ligados</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Definições do monitor</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="106"/>
        <source>Fast Menu</source>
        <translation>Menu rápido</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="110"/>
        <source>Set position</source>
        <translation>Definir posição</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="229"/>
        <source>Advanced settings</source>
        <translation>Definições avançadas</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Configuração</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Resolução:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Ativar este ecrã</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Este é o ecrã principal</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Este ecrã expande para outro</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Taxa de atualização:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Rotação:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Informação do ecrã</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="129"/>
        <source>Name: %1
</source>
        <translation>Nome: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="130"/>
        <source>Vendor: %1
</source>
        <translation>Fabricante: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="131"/>
        <source>Serial: %1
</source>
        <translation>Série: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="132"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Tamanho do ecrã: %1 cm x %2 cm
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="133"/>
        <source>Serial number: %1
</source>
        <translation>Número de série: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="134"/>
        <source>EISA device ID: %1
</source>
        <translation>ID EISA do dispositivo: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="154"/>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="155"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="156"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="157"/>
        <source>Inverted</source>
        <translation>Invertido</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="245"/>
        <source>%1 Hz</source>
        <translation>%1 HZ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Gerir definições guardadas</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Definições alteradas</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Acha que as definições estão corretas?</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="63"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>Falta %n segundo</numerusform>
            <numerusform>Faltam %n segundos</numerusform>
        </translation>
    </message>
</context>
</TS>
